@@ -18,7 +18,7 @@ except ImportError:
     from test.support.os_helper import EnvironmentVarGuard
 from urllib.error import HTTPError
 from urllib.request import install_opener, urlopen
-from mock import patch
+from mock import patch, mock_open
 from http.server import BaseHTTPRequestHandler
 from socketserver import TCPServer
 
@@ -321,6 +321,43 @@ Version: 2.0
             self.assertEqual(meta.upgradable_to.version, "2.0")
             self.assertEqual(meta.upgradable_to.supported, False)
 
+    @patch("builtins.open", new_callable=mock_open)
+    @patch("glob.glob")
+    @patch("os.path.exists")
+    def test_config_parsing(self, mock_exists, mock_glob, mock_file):
+        mock_exists.return_value = True
+        test_configs = [
+            '/etc/update-manager/release-upgrades.d/00-first.cfg',
+            '/etc/update-manager/release-upgrades.d/10-second.cfg',
+            '/etc/update-manager/release-upgrades.d/20-third.cfg',
+        ]
+        mock_glob.return_value = test_configs
+
+        file_contents = {
+            '/etc/update-manager/release-upgrades':
+                '[DEFAULT]\nprompt=lts\n',
+            '/etc/update-manager/release-upgrades.d/10-second.cfg':
+                'Just some invalid things',
+            '/etc/update-manager/release-upgrades.d/20-third.cfg':
+                '[DEFAULT]\nprompt=never\n',
+            '/etc/update-manager/release-upgrades.d/00-first.cfg':
+                '[DEFAULT]\nprompt=lts\n',
+        }
+
+        # Configure mock_open to return different content based on filename
+        def open_side_effect(filename, *args, **kwargs):
+            content = file_contents.get(filename, '')
+            return mock_open(read_data=content).return_value
+
+        mock_file.side_effect = open_side_effect
+
+        meta = MetaReleaseCore()
+        self.assertEqual(meta.prompt, "never")
+
+        mock_glob.return_value = []
+        meta = MetaReleaseCore()
+        self.assertEqual(meta.prompt, "lts")
+
 
 if __name__ == "__main__":
     if len(sys.argv) > 1 and sys.argv[1] == "-v":
